searchData={"items":[{"type":"module","title":"Rizz","doc":"Rizz is an Elixir package for working with RSS Information Zone Zapper (RIZZ) feeds.\n\nRIZZ is a specification for AI-optimized RSS feeds, extending standard RSS 2.0\nwith AI-specific metadata using XML namespaces.","ref":"Rizz.html"},{"type":"function","title":"Rizz.add_item/2","doc":"Adds an item to a RIZZ feed.","ref":"Rizz.html#add_item/2"},{"type":"function","title":"Example - Rizz.add_item/2","doc":"iex> feed = Rizz.new_feed(title: \"AI News Feed\")\n    iex> feed = Rizz.add_item(feed, %{title: \"AI Update\", ai_model: [\"GPT\"]})\n    iex> length(feed.items)\n    1","ref":"Rizz.html#add_item/2-example"},{"type":"function","title":"Rizz.ai_namespace/0","doc":"Returns the AI namespace URI used in RIZZ.","ref":"Rizz.html#ai_namespace/0"},{"type":"function","title":"Example - Rizz.ai_namespace/0","doc":"iex> Rizz.ai_namespace()\n    \"http://xai.org/RIZZ-namespace\"","ref":"Rizz.html#ai_namespace/0-example"},{"type":"function","title":"Rizz.compatible_with_model?/2","doc":"Checks if an entry is compatible with the specified AI model.","ref":"Rizz.html#compatible_with_model?/2"},{"type":"function","title":"Example - Rizz.compatible_with_model?/2","doc":"iex> entry = %{ai_models: [\"GPT\", \"Grok\"]}\n    iex> Rizz.compatible_with_model?(entry, \"GPT\")\n    true","ref":"Rizz.html#compatible_with_model?/2-example"},{"type":"function","title":"Rizz.fetch/2","doc":"Fetches a RIZZ feed from the given URL.","ref":"Rizz.html#fetch/2"},{"type":"function","title":"Options - Rizz.fetch/2","doc":"* `:headers` - HTTP headers for the request, useful for authentication.\n* `:follow_redirects` - Whether to follow redirects. Default is true.","ref":"Rizz.html#fetch/2-options"},{"type":"function","title":"Examples - Rizz.fetch/2","doc":"# Not run in tests - requires HTTP\n    # iex> Rizz.fetch(\"https://example.com/RIZZ.xml\")\n    # {:ok, %Rizz.Feed{}}\n    #\n    # iex> Rizz.fetch(\"https://example.com/RIZZ.xml\",\n    # ...>   headers: [{\"Authorization\", \"Bearer token\"}])\n    # {:ok, %Rizz.Feed{}}","ref":"Rizz.html#fetch/2-examples"},{"type":"function","title":"Rizz.filter_by_model/2","doc":"Filters feed items by AI model compatibility.","ref":"Rizz.html#filter_by_model/2"},{"type":"function","title":"Example - Rizz.filter_by_model/2","doc":"iex> feed = %{entries: [%{ai_models: [\"GPT\", \"Grok\"]}, %{ai_models: [\"Claude\"]}]}\n    iex> gpt_feed = Rizz.filter_by_model(feed, \"GPT\")\n    iex> length(gpt_feed.entries)\n    1","ref":"Rizz.html#filter_by_model/2-example"},{"type":"function","title":"Rizz.filter_by_quality/2","doc":"Filters feed items by AI data quality.","ref":"Rizz.html#filter_by_quality/2"},{"type":"function","title":"Options - Rizz.filter_by_quality/2","doc":"* `:min_quality` - Minimum quality score (0-100). Default is 0.","ref":"Rizz.html#filter_by_quality/2-options"},{"type":"function","title":"Example - Rizz.filter_by_quality/2","doc":"iex> feed = %{entries: [%{ai_data_quality: 90}, %{ai_data_quality: 50}]}\n    iex> quality_feed = Rizz.filter_by_quality(feed, min_quality: 80)\n    iex> length(quality_feed.entries)\n    1","ref":"Rizz.html#filter_by_quality/2-example"},{"type":"function","title":"Rizz.get_ai_context/1","doc":"Gets the AI context for a feed entry.","ref":"Rizz.html#get_ai_context/1"},{"type":"function","title":"Example - Rizz.get_ai_context/1","doc":"iex> entry = %{ai_context: \"Summarize for developers\"}\n    iex> Rizz.get_ai_context(entry)\n    \"Summarize for developers\"","ref":"Rizz.html#get_ai_context/1-example"},{"type":"function","title":"Rizz.get_ai_models/1","doc":"Gets the AI models for a feed entry.","ref":"Rizz.html#get_ai_models/1"},{"type":"function","title":"Example - Rizz.get_ai_models/1","doc":"iex> entry = %{ai_models: [\"GPT\", \"Grok\"]}\n    iex> Rizz.get_ai_models(entry)\n    [\"GPT\", \"Grok\"]","ref":"Rizz.html#get_ai_models/1-example"},{"type":"function","title":"Rizz.get_data_quality/1","doc":"Gets the data quality value for a feed entry.","ref":"Rizz.html#get_data_quality/1"},{"type":"function","title":"Example - Rizz.get_data_quality/1","doc":"iex> entry = %{ai_data_quality: 90}\n    iex> Rizz.get_data_quality(entry)\n    90","ref":"Rizz.html#get_data_quality/1-example"},{"type":"function","title":"Rizz.get_json_ld/1","doc":"Gets the JSON-LD data for a feed entry.","ref":"Rizz.html#get_json_ld/1"},{"type":"function","title":"Example - Rizz.get_json_ld/1","doc":"iex> entry = %{json_ld: %{\"@context\" => \"https://schema.org\"}}\n    iex> Rizz.get_json_ld(entry)\n    %{\"@context\" => \"https://schema.org\"}","ref":"Rizz.html#get_json_ld/1-example"},{"type":"function","title":"Rizz.new_feed/1","doc":"Creates a new RIZZ feed with the given options.","ref":"Rizz.html#new_feed/1"},{"type":"function","title":"Options - Rizz.new_feed/1","doc":"* `:title` - Feed title (required)\n* `:link` - Feed link\n* `:description` - Feed description\n* `:language` - Feed language\n* `:pub_date` - Publication date\n* `:last_build_date` - Last build date\n* `:generator` - Feed generator\n* `:ttl` - Time to live","ref":"Rizz.html#new_feed/1-options"},{"type":"function","title":"Example - Rizz.new_feed/1","doc":"iex> feed = Rizz.new_feed(title: \"AI News Feed\")\n    iex> feed.title\n    \"AI News Feed\"","ref":"Rizz.html#new_feed/1-example"},{"type":"function","title":"Rizz.parse/1","doc":"Parses RIZZ XML content into a Feed struct.","ref":"Rizz.html#parse/1"},{"type":"function","title":"Example - Rizz.parse/1","doc":"iex> xml = ~s(<?xml version=\"1.0\"?>   AI Feed   )\n    iex> {:ok, feed} = Rizz.parse(xml)\n    iex> feed.title\n    \"AI Feed\"","ref":"Rizz.html#parse/1-example"},{"type":"function","title":"Rizz.to_xml/1","doc":"Converts a feed to RIZZ-compliant XML.","ref":"Rizz.html#to_xml/1"},{"type":"function","title":"Example - Rizz.to_xml/1","doc":"iex> feed = Rizz.new_feed(title: \"AI News Feed\")\n    iex> xml = Rizz.to_xml(feed)\n    iex> String.contains?(xml, \" AI News Feed \")\n    true","ref":"Rizz.html#to_xml/1-example"},{"type":"module","title":"Rizz.Builder","doc":"Handles the generation of RIZZ-compliant XML from Feed structs.","ref":"Rizz.Builder.html"},{"type":"function","title":"Rizz.Builder.to_xml/1","doc":"Converts a Feed struct to RIZZ-compliant XML.","ref":"Rizz.Builder.html#to_xml/1"},{"type":"function","title":"Example - Rizz.Builder.to_xml/1","doc":"iex> feed = Rizz.Feed.new(title: \"AI News\", link: \"https://example.com\", description: \"AI updates\")\n    iex> Rizz.Builder.to_xml(feed)\n    \"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?> ... \"","ref":"Rizz.Builder.html#to_xml/1-example"},{"type":"module","title":"Rizz.CLI","doc":"Command-line interface for working with RIZZ feeds.","ref":"Rizz.CLI.html"},{"type":"function","title":"Rizz.CLI.display_feed/2","doc":"Display feed contents.","ref":"Rizz.CLI.html#display_feed/2"},{"type":"function","title":"Rizz.CLI.display_help/0","doc":"Display help information.","ref":"Rizz.CLI.html#display_help/0"},{"type":"function","title":"Rizz.CLI.fetch_command/2","doc":"Fetch a RIZZ feed and display its contents.","ref":"Rizz.CLI.html#fetch_command/2"},{"type":"function","title":"Rizz.CLI.main/1","doc":"Main entry point for the CLI.","ref":"Rizz.CLI.html#main/1"},{"type":"module","title":"Rizz.Feed","doc":"Type definition and helpers for RIZZ feeds.\n\nRIZZ feeds extend standard RSS feeds with AI-specific metadata.","ref":"Rizz.Feed.html"},{"type":"function","title":"Rizz.Feed.add_item/2","doc":"Adds an item to the feed.","ref":"Rizz.Feed.html#add_item/2"},{"type":"function","title":"Example - Rizz.Feed.add_item/2","doc":"iex> feed = Rizz.Feed.new(title: \"AI News\")\n    iex> Rizz.Feed.add_item(feed, %{title: \"Update\", description: \"New model\", ai_model: [\"GPT\"]})\n    %Rizz.Feed{title: \"AI News\", items: [%Rizz.Item{title: \"Update\"}]}","ref":"Rizz.Feed.html#add_item/2-example"},{"type":"function","title":"Rizz.Feed.from_standard_feed/2","doc":"Converts a standard ElixirFeedParser feed to RIZZ format.","ref":"Rizz.Feed.html#from_standard_feed/2"},{"type":"function","title":"Rizz.Feed.new/1","doc":"Creates a new feed with the given properties.","ref":"Rizz.Feed.html#new/1"},{"type":"function","title":"Example - Rizz.Feed.new/1","doc":"iex> feed = Rizz.Feed.new(title: \"AI News\")\n    iex> feed.title\n    \"AI News\"","ref":"Rizz.Feed.html#new/1-example"},{"type":"type","title":"Rizz.Feed.t/0","doc":"","ref":"Rizz.Feed.html#t:t/0"},{"type":"module","title":"Rizz.Item","doc":"Represents an item in a RIZZ feed, including AI-specific metadata.","ref":"Rizz.Item.html"},{"type":"function","title":"Rizz.Item.compatible_with_model?/2","doc":"Checks if an item is compatible with the specified AI model.","ref":"Rizz.Item.html#compatible_with_model?/2"},{"type":"function","title":"Example - Rizz.Item.compatible_with_model?/2","doc":"iex> item = Rizz.Item.new(%{ai_model: [\"GPT\", \"Grok\"]})\n    iex> Rizz.Item.compatible_with_model?(item, \"GPT\")\n    true\n\n    iex> Rizz.Item.compatible_with_model?(item, \"Claude\")\n    false","ref":"Rizz.Item.html#compatible_with_model?/2-example"},{"type":"function","title":"Rizz.Item.data_quality/1","doc":"Returns the data quality of an item.","ref":"Rizz.Item.html#data_quality/1"},{"type":"function","title":"Example - Rizz.Item.data_quality/1","doc":"iex> item = Rizz.Item.new(%{ai_data_quality: 85})\n    iex> Rizz.Item.data_quality(item)\n    85\n\n    iex> item = Rizz.Item.new(%{})\n    iex> Rizz.Item.data_quality(item)\n    0","ref":"Rizz.Item.html#data_quality/1-example"},{"type":"function","title":"Rizz.Item.new/1","doc":"Creates a new RIZZ feed item with the given attributes.","ref":"Rizz.Item.html#new/1"},{"type":"function","title":"Example - Rizz.Item.new/1","doc":"iex> Rizz.Item.new(%{title: \"AI Update\", description: \"New models\", ai_model: [\"GPT\", \"Grok\"]})\n    %Rizz.Item{title: \"AI Update\", description: \"New models\", ai_model: [\"GPT\", \"Grok\"]}","ref":"Rizz.Item.html#new/1-example"},{"type":"type","title":"Rizz.Item.t/0","doc":"","ref":"Rizz.Item.html#t:t/0"},{"type":"module","title":"Rizz.Parser","doc":"Responsible for parsing RIZZ XML feeds into Elixir data structures.\n\nUses ElixirFeedParser as the base parser and extends it with AI metadata\nfrom the RIZZ specification.","ref":"Rizz.Parser.html"},{"type":"function","title":"Rizz.Parser.enhance_with_ai_metadata/2","doc":"Enhances a standard feed with RIZZ AI metadata.","ref":"Rizz.Parser.html#enhance_with_ai_metadata/2"},{"type":"function","title":"Rizz.Parser.extract_json_ld/1","doc":"Extracts JSON-LD data from a script tag if present.","ref":"Rizz.Parser.html#extract_json_ld/1"},{"type":"function","title":"Rizz.Parser.parse/1","doc":"Parses a RIZZ XML string into a Feed struct.","ref":"Rizz.Parser.html#parse/1"},{"type":"function","title":"Example - Rizz.Parser.parse/1","doc":"iex> xml = \"<?xml version=\\\"1.0\\\"?>   Feed   \"\n    iex> {:ok, feed} = Rizz.Parser.parse(xml)\n    iex> feed.title\n    \"Feed\"","ref":"Rizz.Parser.html#parse/1-example"},{"type":"function","title":"Rizz.Parser.parse_models/1","doc":"Parses the AI models string into a list of model names.","ref":"Rizz.Parser.html#parse_models/1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}